@@ -35,8 +35,6 @@ def parse_args():
                         action="store_true")
     parser.add_argument("--thotsbay-username", type=str, help="username to login to thotsbay", default=None)
     parser.add_argument("--thotsbay-password", type=str, help="password to login to thotsbay", default=None)
-    parser.add_argument("--cyberfile-username", type=str, help="username to login to cyberfile", default=None)
-    parser.add_argument("--cyberfile-password", type=str, help="password to login to cyberfile", default=None)
     parser.add_argument("links", metavar="link", nargs="*",
                         help="link to content to download (passing multiple links is supported)", default=[])
     args = parser.parse_args()
@@ -62,8 +60,7 @@ async def download_all(args: argparse.Namespace):
     with open(input_file, "r") as f:
         links += await regex_links(f.read())
     thotsbay_auth = AuthData(args.thotsbay_username, args.thotsbay_password)
-    cyberfile_auth = AuthData(args.cyberfile_username, args.cyberfile_password)
-    content_object = await scrape(links, args.include_id, thotsbay_auth, cyberfile_auth, args.separate_posts)
+    content_object = await scrape(links, args.include_id, thotsbay_auth, args.separate_posts)
     if await content_object.is_empty():
         logging.error(f'ValueError No links')
         await log("No links found, check the URL.txt\nIf the link works in your web browser, "
