@@ -1,7 +1,6 @@
 import logging
 import os
 import re
-import sqlite3
 import ssl
 
 import certifi
@@ -27,7 +26,7 @@ FILE_FORMATS = {
         '.mp3', '.flac', '.wav', '.m4a'
     },
     'Other': {
-        '.json', '.torrent', '.zip', '.rar'
+        '.json', '.torrent', '.zip', '.rar', '.7z'
     }
 }
 
@@ -43,40 +42,6 @@ async def sanitize(input: str) -> str:
     return re.sub(r'[<>:"/\\|?*\']', "", input)
 
 
-async def sql_initialize(download_history):
-    conn = sqlite3.connect(download_history)
-    curr = conn.cursor()
-    create_table_query = """CREATE TABLE IF NOT EXISTS downloads (
-                                filename TEXT,
-                                size INTEGER NOT NULL,
-                                completed INTEGER NOT NULL,
-                                PRIMARY KEY (filename, size)
-                            );"""
-    curr.execute(create_table_query)
-
-    conn.commit()
-    return conn, curr
-
-
-async def sql_check_existing(cursor: sqlite3.Cursor, filename, size):
-    cursor.execute("""SELECT completed FROM downloads WHERE filename = '%s' and size = %d""" % (filename, size))
-    sql_file_check = cursor.fetchone()
-    if sql_file_check:
-        if sql_file_check[0] == 1:
-            return True
-    return False
-
-
-async def sql_insert_file(connection: sqlite3.Connection, cursor: sqlite3.Cursor, filename, size, completed):
-    cursor.execute("""INSERT OR IGNORE INTO downloads VALUES ('%s', %d, %d)""" % (filename, size, completed))
-    connection.commit()
-
-
-async def sql_update_file(connection: sqlite3.Connection, cursor: sqlite3.Cursor, filename, size, completed):
-    cursor.execute("""INSERT OR REPLACE INTO downloads VALUES ('%s', %d, %d)""" % (filename, size, completed))
-    connection.commit()
-
-
 async def log(text, style=Fore.WHITE) -> None:
     """Wrapper around print() to add color to text"""
     logger.debug(text)
@@ -100,8 +65,8 @@ async def purge_dir(dir, in_place=True):
 
     for tree_element in dir_tree:
         sub_dir = tree_element[0]
-        is_empty = not len(os.listdir(sub_dir))
-        if is_empty:
+        dir_count = len(os.listdir(sub_dir))
+        if dir_count == 0: # Helps with readability and i've had issues with it deleting non-empty dirs
             deleted.append(sub_dir)
 
     if in_place:
@@ -111,7 +76,8 @@ async def purge_dir(dir, in_place=True):
 
 
 async def regex_links(urls) -> list:
-    all_links = [x.group().replace(".md.", ".") for x in re.finditer(r"(?:http.*?)(?=('|$|\n|\r\n|\r|\s|\"|\[/URL]|]\[|\[/img]))", urls)]
+    all_links = [x.group().replace(".md.", ".") for x in re.finditer(
+        r"(?:http.*?)(?=('|$|\n|\r\n|\r|\s|\"|\[/URL]|]\[|\[/img]))", urls)]
     yarl_links = []
     for link in all_links:
         yarl_links.append(URL(link))
@@ -131,7 +97,8 @@ async def bunkr_parse(url: URL) -> URL:
 
 
 async def cyberdrop_parse(url: URL) -> URL:
-    mapping_direct = [r'img-...cyberdrop...', r'f.cyberdrop...', r'fs-...cyberdrop...']
+    mapping_direct = [r'img-...cyberdrop...',
+                      r'f.cyberdrop...', r'fs-...cyberdrop...']
     url = str(url)
     for mapping in mapping_direct:
         url = re.sub(mapping, 'cyberdrop.to', url)
@@ -143,7 +110,8 @@ async def pixeldrain_parse(url: URL, title: str) -> URL:
     if url.parts[1] == 'l':
         final_url = URL('https://pixeldrain.com/api/list/') / title / 'zip'
     else:
-        final_url = (URL('https://pixeldrain.com/api/file/') / title).with_query('download')
+        final_url = (URL('https://pixeldrain.com/api/file/') /
+                     title).with_query('download')
     return final_url
 
 
